#!/usr/bin/env python

###########
# Imports
####
import sys
import os
import logging

from insights_client import constants as insights_constants


class OCPCoordinatorLogger:

    # Containers
    logger = None
    constants = None
    verbose = False
    config = None
    interactive = None

    # Constructor
    def __init__(self, ap_constants, ap_config, verbose=False):
        self.constants = ap_constants
        self.config = ap_config
        self.verbose = verbose
        self.logger = self.set_up_logging(ap_constants)

    # Set the verbose level, currently True or False
    # Need to incorporate a DEBUG/INFO level at some point
    def set_verbosity(self, verbosity):
        self.verbose = verbosity

    # Get interactive
    def get_interactive(self):
        if not self.interactive:
            self.interactive = self.config.get_config_var('interactive')
        return self.interactive

    #############################################
    # Set up Logging, pass to RHEV Coordinator
    ####
    def set_up_logging(self, ocp_constants):
        logging_dir = insights_constants.log_dir
        if not os.path.exists(logging_dir):
                os.makedirs(logging_dir, 0700)
        logging_file = os.path.join(logging_dir, ocp_constants.logging_file)
        my_logger = logging.getLogger(ocp_constants.logger_name)
        my_logger.setLevel(logging.DEBUG)
        handler = logging.handlers.RotatingFileHandler(logging_file, backupCount=ocp_constants.log_backup_count)
        formatter = logging.Formatter(ocp_constants.log_formatter)
        handler.setFormatter(formatter)
        my_logger.addHandler(handler)
        return my_logger

    ###############
    # Verbose log
    ####
    def vlog(self, text, level="INFO"):
        if level == "ERROR":
            self.logger.error(text)
        elif level == "DEBUG":
            self.logger.debug(text)
        elif level == "INFO":
            self.logger.info(text)
        else:
            self.logger.info(text)

        interactive = self.get_interactive()

        if self.verbose and interactive:
            continue_string = "%s (Continue? YyENTER/Nn): " % text
            yes_values = ['y', 'yes', 'yea', 'yeah', 'yep', 'mmmhmm']
            no_values = ['n', 'no', 'nope', 'naw', 'nah']
            continue_execution = raw_input(continue_string).lower().strip().rstrip() or True
            while not continue_execution  and (continue_execution not in yes_values) and (continue_execution not in no_values):
                continue_execution = raw_input(continue_string).lower().strip().rstrip() or True
            if not continue_execution or continue_execution in no_values:
                sys.exit("Interactive mode exiting Coordinator Insights execution...")
        elif self.verbose:
            print text

