#!/usr/bin/env python

##########
# Imports
####
import optparse


class OCPCoordinatorParser:

    # Containers
    parser = None
    constants = None
    config = None
    options = None

    # Constructor
    def __init__(self, ocp_constants, ocp_config):
        self.constants = ocp_constants
        self.config = ocp_config
        self.setup_options()
        self.setup_parser()

    # Setup the Options
    def setup_options(self):
        self.options = [

            # Make this thing interactive
            # This is for debugging, goes through the logger and asks you if you want to continue to the next step
            optparse.make_option('-i', '--interactive', dest='interactive',
                                 help="This must be flagged with --verbose. This prompts for the execution of each step.",
                                 action='store_true',
                                 default=self.config.get_config_var('interactive')),

            # Make things Verbose
            optparse.make_option('-v', '--verbose', dest='verbose',
                                 help='In addition to logging to the Coordinator Logs, print output to the console.',
                                 action='store_true',
                                 default=self.config.get_config_var('verbose')),

            # Archive Only
            optparse.make_option('--archive-only', dest='archive_only',
                                 help='Only create the Coordinator Archive in /tmp. This will not upload the final Archive to Red Hat.',
                                 action='store_true',
                                 default=self.config.get_config_var('archive_only')),

            # Disable Cron
            optparse.make_option('--disable-cron', dest='disable_cron',
                                 help='Will unlink and disable the Coordinator Cron Job.',
                                 action='store_true',
                                 default=self.constants.disable_cron),

            # Enable Cron
            optparse.make_option('--enable-cron', dest='enable_cron',
                                 help='Will link and enable the Coordinator Cron Job.',
                                 action='store_true',
                                 default=self.config.get_config_var('enable_cron')),

            # Configure
            optparse.make_option('--configure', dest='configure',
                                 help='Will run the Coordinator configuration utility. This will re-write the Coordinator configuration file to /etc/insights-client/insights-coordinator-rhev.conf. After running the utility the Coordinator will exit.',
                                 action='store_true',
                                 default=self.constants.configure),

            optparse.make_option('--group', dest='group',
                                 help='Name of the group to hold all the nodes for this Open Shift cluster.',
                                 action='store', type='string',
                                 default=self.config.get_config_var('group'))
        ]

    # Setup the Parser
    def setup_parser(self):
        self.parser = optparse.OptionParser(usage=self.get_usage(), option_list=self.get_options())

    # Get the options
    def get_options(self):
        return self.options

    # Get the parser usage
    def get_usage(self):
        return self.constants.coordinator_parser_usage

    # Parse options
    def parse_options(self):
        # Parse all of the options
        options = self.parser.parse_args()
        options = options[0]

        # Override any existing configuration values with temporary options
        for option_key in [option for option in dir(options) if not option.startswith('_') and not option.endswith('_')]:
            self.config.set_temp_config_var(option_key, getattr(options, option_key))

        # Return only the parsed options, don't need to return additional arguments
        return options
